# Optical data

## Implemented optical satellites

|Satellites | Class | Product Types | Use archive | Default Resolution |
|--- | --- | --- | --- | ---|
|Sentinel-2 | {meth}`~eoreader.products.optical.s2_product.S2Product` | L1C & L2A | Yes | 20m|
|Sentinel-2 Theia | {meth}`~eoreader.products.optical.s2_theia_product.S2TheiaProduct` | L2A | Yes | 20m|
|Sentinel-3 SLSTR | {meth}`~eoreader.products.optical.s3_product.S3Product` | RBT | No | 300m|
|Sentinel-3 OLCI | {meth}`~eoreader.products.optical.s3_product.S3Product` | EFR | No | 500m|
|Landsat 8 OLCI | {meth}`~eoreader.products.optical.l8_product.L8Product` | Level 1 | Collection 1: No, Collection 2: Yes | 30m|
|Landsat 7 ETM | {meth}`~eoreader.products.optical.l7_product.L7Product` | Level 1 | Collection 1: No, Collection 2: Yes | 30m|
|Landsat 5 TM | {meth}`~eoreader.products.optical.l5_product.L5Product` | Level 1 | Collection 1: No, Collection 2: Yes | 30m|
|Landsat 4 TM | {meth}`~eoreader.products.optical.l4_product.L4Product` | Level 1 | Collection 1: No, Collection 2: Yes | 30m|
|Landsat 5 MSS | {meth}`~eoreader.products.optical.l5_product.L5Product` | Level 1 | Collection 1: No, Collection 2: Yes | 60m|
|Landsat 4 MSS | {meth}`~eoreader.products.optical.l4_product.L4Product` | Level 1 | Collection 1: No, Collection 2: Yes | 60m|
|Landsat 3 MSS | {meth}`~eoreader.products.optical.l3_product.L3Product` | Level 1 | Collection 1: No, Collection 2: Yes | 60m|
|Landsat 2 MSS | {meth}`~eoreader.products.optical.l2_product.L2Product` | Level 1 | Collection 1: No, Collection 2: Yes | 60m|
|Landsat 1 MSS | {meth}`~eoreader.products.optical.l1_product.L1Product` | Level 1 | Collection 1: No, Collection 2: Yes | 60m|
|PlanetScope | {meth}`~eoreader.products.optical.pla_product.PlaProduct` | L3A & L3B | Yes | 3m|
|Pleiades | {meth}`~eoreader.products.optical.pld_product.PldProduct` | SEN, PRJ, ORT & MOS | Yes | 0.5 or 2m|
|SPOT 7 | {meth}`~eoreader.products.optical.spot7_product.Spot7Product` | SEN, PRJ, ORT & MOS | Yes | 1.5 or 6m|
|SPOT 6 | {meth}`~eoreader.products.optical.spot6_product.Spot6Product` | SEN, PRJ, ORT & MOS | Yes | 1.5 or 6m|

```{warning}
Satellites products that cannot be used as archived have to be extracted before use.
```

## Optical bands

The following bands are available in **EOReader**, but may not be available for all sensors.

### Satellite bands

#### Band names

These bands are mainly based on Sentinel-2 bands with some additions:

- {meth}`~eoreader.bands.bands.OpticalBandNames.CA`: Coastal Aerosol
- {meth}`~eoreader.bands.bands.OpticalBandNames.BLUE`
- {meth}`~eoreader.bands.bands.OpticalBandNames.GREEN`
- {meth}`~eoreader.bands.bands.OpticalBandNames.RED`
- {meth}`~eoreader.bands.bands.OpticalBandNames.VRE_1`: Vegetation Red Edge 1
- {meth}`~eoreader.bands.bands.OpticalBandNames.VRE_2`: Vegetation Red Edge 2
- {meth}`~eoreader.bands.bands.OpticalBandNames.VRE_3`: Vegetation Red Edge 3
- {meth}`~eoreader.bands.bands.OpticalBandNames.NIR`: Near Infrared
- {meth}`~eoreader.bands.bands.OpticalBandNames.NARROW_NIR`: Narrow Near Infrared (band `8A` for `Sentinel-2`)
- {meth}`~eoreader.bands.bands.OpticalBandNames.WV`: Water vapour
- {meth}`~eoreader.bands.bands.OpticalBandNames.SWIR_CIRRUS`
- {meth}`~eoreader.bands.bands.OpticalBandNames.SWIR_1`
- {meth}`~eoreader.bands.bands.OpticalBandNames.SWIR_2`
- {meth}`~eoreader.bands.bands.OpticalBandNames.PAN`: Panchromatic
- {meth}`~eoreader.bands.bands.OpticalBandNames.TIR_1`: Thermal Infrared 1
- {meth}`~eoreader.bands.bands.OpticalBandNames.TIR_2`: Thermal Infrared 2

#### Optical band mapping between sensors

|Bands (names) | Coastal aerosol | Blue | Green | Red | Vegetation red edge | Vegetation red edge | Vegetation red edge | NIR | Narrow NIR | Water vapor | SWIR – Cirrus | SWIR | SWIR | Panchromatic | Thermal IR | Thermal IR|
|--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---|
|**Bands (alias)** | `CA` | `BLUE` | `GREEN` | `RED` | `VRE_1` | `VRE_2` | `VRE_3` | `NIR` | `NARROW_NIR` | `WV` | `SWIR_CIRRUS` | `SWIR_1` | `SWIR_2` | `PAN` | `TIR_1` | `TIR_2`|
|Sentinel-2 | **1** (60m) | **2** (10m) | **3** (10m) | **4** (10m) | **5** (20m) |**6** (20m) |**7** (20m) |**8** (10m) | **8A** (20m) |**9** (60m) |**10** (60m) |**11** (20m) |**12** (20m) |  |  | |
|Sentinel-2 Theia | *Not available* | **2** (10m) |**3** (10m) | **4** (10m) | **5** (20m) |**6** (20m) |**7** (20m) |**8** (10m) | **8A** (20m) | *Not available* |**10** (60m) |**11** (20m) |**12** (20m) |  |  | |
|Sentinel-3 OLCI* | **2** (300m) | **3** (300m) |**6** (300m) |**8** (300m) |**11** (300m) |**12** (300m) | **16** (300m) | **17** (300m) | **17** (300m) | **20** (300m) |  |  |  |  |  | |
|Sentinel-3 SLSTR* | | | **1** (500m) | **2** (500m) |  |  |  |**3** (500m) |**3** (500m) |  | **4** (500m) | **5** (500m) |**6** (500m) | |**8** (1km) |**9** (1km)|
|Landsat OLCI (8) | **1** (30m) | **2** (30m) | **3** (30m) | **4** (30m) |  |  |  | **5** (30m) | **5** (30m) |  |**9** (30m) |**6** (30m) |**7** (30m) |**8** (15m) |**10** (100m) |**11** (100m)|
|Landsat ETM (7)|  | **1** (30m) | **2** (30m) | **3** (30m) |  |  |  | **4** (30m) | **4** (30m) |  |  | **5** (30m) |**7** (30m) |**8** (15m) |**6** (60m) |**6** (60m)|
|Landsat TM (5-4)|  | **1** (30m) | **2** (30m) | **3** (30m) |  |  |  | **4**(30m) | **4** (30m) |  |  | **5** (30m) |**7** (30m) |  |**6** (120m) |**6** (120m)|
|Landsat MSS (5-4)|  |  | **1** (60m) | **2** (60m) | **3** (60m) | **3** (60m) | **3** (60m) | **4** (60m) | **4** (60m) |  |  |  |  |  |  | |
|Landsat MSS (1-3)|  |  | **4** (60m) | **5** (60m) | **6** (60m) | **6** (60m) | **6** (60m) | **7** (60m) | **7** (60m) |  |  |  |  |  |**8** (240m)<br>*only for Landsat 3* |**8** (240m)<br>*only for Landsat 3*|
|PlanetScope (4 band)|  | **1** (3m) | **2** (3m) | **3** (3m) | |  | | **4** (3m) | **4** (3m) |  |  |  |  |  | | |
|PlanetScope (5 band)|  | **1** (3m) | **2** (3m) | **3** (3m) |**4** (3m)|  || **5** (3m) | **5** (3m) |  |  |  |  |  | | |
|Pleiades** (PMS/MS)|  | **3** (0.5/2m) | **2** (0.5/2m) | **1** (0.5/2m) | | | | **4** (0.5/2m) | **4** (0.5/2m) |  |  |  |  |  | | |
|SPOT 6-7** (PMS/MS)|  | **3** (1.5/6m) | **2** (1.5/6m) | **1** (1.5/6m) | | | | **4** (1.5/6m) | **4** (1.5/6m) |  |  |  |  |  | | |

\* *Not all bands of this sensor are used in EOReader*  
\*\* *P(panchro) have only one panchromatic band, P/MS-N have 3 bands (BGR), and P/MS-X also have 3 bands in false color (GRNIR)*

<div>                        <script type="text/javascript">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>
        <script src="https://cdn.plot.ly/plotly-2.4.2.min.js"></script>                <div id="04e4f9e3-57fa-436c-b003-505f963a2fb8" class="plotly-graph-div" style="height:700px; width:1100px;"></div>            <script type="text/javascript">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("04e4f9e3-57fa-436c-b003-505f963a2fb8")) {                    Plotly.newPlot(                        "04e4f9e3-57fa-436c-b003-505f963a2fb8",                        [{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | SWIR_2</b><br>Central Wavelength: 2190nm<br>Bandwidth: 180nm<br>Resolution: 20m<br>Band Number: 12","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | SWIR_1</b><br>Central Wavelength: 1610nm<br>Bandwidth: 90nm<br>Resolution: 20m<br>Band Number: 11","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | CIRRUS</b><br>Central Wavelength: 1380nm<br>Bandwidth: 30nm<br>Resolution: 60m<br>Band Number: 10","line":{"color":"slategrey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | WATER_VAPOUR</b><br>Central Wavelength: 945nm<br>Bandwidth: 20nm<br>Resolution: 60m<br>Band Number: 09","line":{"color":"darkgrey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | NIR</b><br>Central Wavelength: 842nm<br>Bandwidth: 115nm<br>Resolution: 10m<br>Band Number: 08","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | NARROW_NIR</b><br>Central Wavelength: 865nm<br>Bandwidth: 20nm<br>Resolution: 20m<br>Band Number: 8a","line":{"color":"rgb(177,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | VEGETATION_RED_EDGE_3</b><br>Central Wavelength: 783nm<br>Bandwidth: 20nm<br>Resolution: 20m<br>Band Number: 07","line":{"color":"rgb(196,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | VEGETATION_RED_EDGE_2</b><br>Central Wavelength: 740nm<br>Bandwidth: 15nm<br>Resolution: 20m<br>Band Number: 06","line":{"color":"rgb(216,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 705nm<br>Bandwidth: 15nm<br>Resolution: 20m<br>Band Number: 05","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | RED</b><br>Central Wavelength: 665nm<br>Bandwidth: 30nm<br>Resolution: 10m<br>Band Number: 04","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | GREEN</b><br>Central Wavelength: 560nm<br>Bandwidth: 35nm<br>Resolution: 10m<br>Band Number: 03","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | BLUE</b><br>Central Wavelength: 490nm<br>Bandwidth: 65nm<br>Resolution: 10m<br>Band Number: 02","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-2 MSI | COASTAL_AEROSOL</b><br>Central Wavelength: 443nm<br>Bandwidth: 20nm<br>Resolution: 60m<br>Band Number: 01","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,0.1,0.1,0.1,0.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | WATER_VAPOUR</b><br>Central Wavelength: 940nm<br>Bandwidth: 40nm<br>Resolution: 300m<br>Band Number: 20","line":{"color":"darkgrey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | NIR</b><br>Central Wavelength: 865nm<br>Bandwidth: 20nm<br>Resolution: 300m<br>Band Number: 17","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | VEGETATION_RED_EDGE_3</b><br>Central Wavelength: 778.75nm<br>Bandwidth: 15nm<br>Resolution: 300m<br>Band Number: 16","line":{"color":"rgb(196,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | VEGETATION_RED_EDGE_2</b><br>Central Wavelength: 753.75nm<br>Bandwidth: 7.5nm<br>Resolution: 300m<br>Band Number: 12","line":{"color":"rgb(216,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 708.75nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 11","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | RED</b><br>Central Wavelength: 665nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 08","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | GREEN</b><br>Central Wavelength: 560nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 06","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | BLUE</b><br>Central Wavelength: 490nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 04","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 OLCI | COASTAL_AEROSOL</b><br>Central Wavelength: 442.5nm<br>Bandwidth: 10nm<br>Resolution: 300m<br>Band Number: 03","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,1.1,1.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | SWIR_2</b><br>Central Wavelength: 2255.7nm<br>Bandwidth: 50.15nm<br>Resolution: 500m<br>Band Number: 06","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | SWIR_1</b><br>Central Wavelength: 1613.4nm<br>Bandwidth: 60.68nm<br>Resolution: 500m<br>Band Number: 05","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | CIRRUS</b><br>Central Wavelength: 1374.8nm<br>Bandwidth: 20.8nm<br>Resolution: 500m<br>Band Number: 04","line":{"color":"slategrey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | NIR</b><br>Central Wavelength: 868.0nm<br>Bandwidth: 20.6nm<br>Resolution: 500m<br>Band Number: 03","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | RED</b><br>Central Wavelength: 659.47nm<br>Bandwidth: 19.25nm<br>Resolution: 500m<br>Band Number: 02","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Sentinel-3 SLSTR | GREEN</b><br>Central Wavelength: 554.27nm<br>Bandwidth: 19.26nm<br>Resolution: 500m<br>Band Number: 01","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,2.1,2.1,2.1,2.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | PANCHROMATIC</b><br>Central Wavelength: 590.0nm<br>Bandwidth: 180nm<br>Resolution: 15m<br>Band Number: 08","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | SWIR_2</b><br>Central Wavelength: 2200.0nm<br>Bandwidth: 180nm<br>Resolution: 30m<br>Band Number: 07","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | SWIR_1</b><br>Central Wavelength: 1610.0nm<br>Bandwidth: 80nm<br>Resolution: 30m<br>Band Number: 06","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | CIRRUS</b><br>Central Wavelength: 1370.0nm<br>Bandwidth: 20nm<br>Resolution: 30m<br>Band Number: 09","line":{"color":"slategrey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | NIR</b><br>Central Wavelength: 865.0nm<br>Bandwidth: 30nm<br>Resolution: 30m<br>Band Number: 05","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | RED</b><br>Central Wavelength: 655.0nm<br>Bandwidth: 30nm<br>Resolution: 30m<br>Band Number: 04","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 60nm<br>Resolution: 30m<br>Band Number: 03","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | BLUE</b><br>Central Wavelength: 480.0nm<br>Bandwidth: 60nm<br>Resolution: 30m<br>Band Number: 02","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat OLCI | COASTAL_AEROSOL</b><br>Central Wavelength: 440.0nm<br>Bandwidth: 20nm<br>Resolution: 30m<br>Band Number: 01","line":{"color":"lightskyblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,3.1,3.1,3.1,3.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | PANCHROMATIC</b><br>Central Wavelength: 710.0nm<br>Bandwidth: 380nm<br>Resolution: 15m<br>Band Number: 08","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | SWIR_2</b><br>Central Wavelength: 2220.0nm<br>Bandwidth: 260nm<br>Resolution: 30m<br>Band Number: 07","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | SWIR_1</b><br>Central Wavelength: 1650.0nm<br>Bandwidth: 200nm<br>Resolution: 30m<br>Band Number: 05","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | NIR</b><br>Central Wavelength: 835.0nm<br>Bandwidth: 130nm<br>Resolution: 30m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 60nm<br>Resolution: 30m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 80nm<br>Resolution: 30m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat ETM+ | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 70nm<br>Resolution: 30m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,4.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | SWIR_2</b><br>Central Wavelength: 2215.0nm<br>Bandwidth: 270nm<br>Resolution: 30m<br>Band Number: 07","line":{"color":"rgb(98,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | SWIR_1</b><br>Central Wavelength: 1650.0nm<br>Bandwidth: 200nm<br>Resolution: 30m<br>Band Number: 05","line":{"color":"rgb(118,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | NIR</b><br>Central Wavelength: 830.0nm<br>Bandwidth: 140nm<br>Resolution: 30m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 60nm<br>Resolution: 30m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | GREEN</b><br>Central Wavelength: 560.0nm<br>Bandwidth: 80nm<br>Resolution: 30m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat TM | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 70nm<br>Resolution: 30m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,5.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat MSS | NIR</b><br>Central Wavelength: 950.0nm<br>Bandwidth: 300nm<br>Resolution: 60m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat MSS | VEGETATION_RED_EDGE_1</b><br>Central Wavelength: 750.0nm<br>Bandwidth: 100nm<br>Resolution: 60m<br>Band Number: 03","line":{"color":"rgb(235,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat MSS | RED</b><br>Central Wavelength: 650.0nm<br>Bandwidth: 100nm<br>Resolution: 60m<br>Band Number: 02","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Landsat MSS | GREEN</b><br>Central Wavelength: 550.0nm<br>Bandwidth: 100nm<br>Resolution: 60m<br>Band Number: 01","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,6.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | NIR</b><br>Central Wavelength: 820.0nm<br>Bandwidth: 80nm<br>Resolution: 3m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | RED</b><br>Central Wavelength: 630.0nm<br>Bandwidth: 80nm<br>Resolution: 3m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | GREEN</b><br>Central Wavelength: 545.0nm<br>Bandwidth: 90nm<br>Resolution: 3m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>PlanetScope | BLUE</b><br>Central Wavelength: 485.0nm<br>Bandwidth: 60nm<br>Resolution: 3m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,7.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | PANCHROMATIC</b><br>Central Wavelength: 655.0nm<br>Bandwidth: 350nm<br>Resolution: 0.5m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,8.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | NIR</b><br>Central Wavelength: 790.0nm<br>Bandwidth: 80nm<br>Resolution: 3m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 120nm<br>Resolution: 3m<br>Band Number: 01","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | GREEN</b><br>Central Wavelength: 550.0nm<br>Bandwidth: 120nm<br>Resolution: 3m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Pleiades | BLUE</b><br>Central Wavelength: 490.0nm<br>Bandwidth: 120nm<br>Resolution: 3m<br>Band Number: 03","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,8.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6 | PANCHROMATIC</b><br>Central Wavelength: 599.5nm<br>Bandwidth: 289nm<br>Resolution: 1.5m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,9.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6 | NIR</b><br>Central Wavelength: 818.0nm<br>Bandwidth: 124nm<br>Resolution: 6m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6 | RED</b><br>Central Wavelength: 659.0nm<br>Bandwidth: 70nm<br>Resolution: 3m<br>Band Number: 01","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6 | GREEN</b><br>Central Wavelength: 557.0nm<br>Bandwidth: 60nm<br>Resolution: 6m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-6 | BLUE</b><br>Central Wavelength: 486.5nm<br>Bandwidth: 65nm<br>Resolution: 6m<br>Band Number: 03","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,9.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-7 | PANCHROMATIC</b><br>Central Wavelength: 599.5nm<br>Bandwidth: 289nm<br>Resolution: 1.5m<br>Band Number: NA","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,10.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-7 | NIR</b><br>Central Wavelength: 818.0nm<br>Bandwidth: 124nm<br>Resolution: 6m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-7 | RED</b><br>Central Wavelength: 659.0nm<br>Bandwidth: 70nm<br>Resolution: 3m<br>Band Number: 01","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-7 | GREEN</b><br>Central Wavelength: 557.0nm<br>Bandwidth: 60nm<br>Resolution: 6m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>Spot-7 | BLUE</b><br>Central Wavelength: 486.5nm<br>Bandwidth: 65nm<br>Resolution: 6m<br>Band Number: 03","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,10.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView02/03 | PANCHROMATIC</b><br>Central Wavelength: 625.0nm<br>Bandwidth: 350nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,11.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView02/03 | NIR</b><br>Central Wavelength: 832.5nm<br>Bandwidth: 125nm<br>Resolution: 2m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView02/03 | RED</b><br>Central Wavelength: 660.0nm<br>Bandwidth: 60nm<br>Resolution: 2m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView02/03 | GREEN</b><br>Central Wavelength: 545.0nm<br>Bandwidth: 70nm<br>Resolution: 2m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView02/03 | BLUE</b><br>Central Wavelength: 480.0nm<br>Bandwidth: 60nm<br>Resolution: 2m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,11.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView04/GeoEye01 | PANCHROMATIC</b><br>Central Wavelength: 625.0nm<br>Bandwidth: 350nm<br>Resolution: 0.5m<br>Band Number: 01","line":{"color":"grey","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,12.0,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView04/GeoEye01 | NIR</b><br>Central Wavelength: 850.0nm<br>Bandwidth: 140nm<br>Resolution: 2m<br>Band Number: 04","line":{"color":"rgb(157,0,0)","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView04/GeoEye01 | RED</b><br>Central Wavelength: 672.5nm<br>Bandwidth: 35nm<br>Resolution: 2m<br>Band Number: 03","line":{"color":"red","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.1,12.1,12.1,12.1,12.1,12.1,12.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView04/GeoEye01 | GREEN</b><br>Central Wavelength: 545.0nm<br>Bandwidth: 70nm<br>Resolution: 2m<br>Band Number: 02","line":{"color":"green","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]},{"hoverinfo":"x+text","hovertemplate":"<b>WorldView04/GeoEye01 | BLUE</b><br>Central Wavelength: 480.0nm<br>Bandwidth: 60nm<br>Resolution: 2m<br>Band Number: 01","line":{"color":"dodgerblue","width":20},"name":"","showlegend":false,"type":"scatter","x":[350.0,355.0122249388753,360.0244498777506,365.0366748166259,370.0488997555012,375.06112469437653,380.07334963325184,385.08557457212714,390.09779951100245,395.11002444987776,400.12224938875306,405.13447432762837,410.1466992665037,415.158924205379,420.1711491442543,425.1833740831296,430.1955990220049,435.2078239608802,440.2200488997555,445.2322738386308,450.2444987775061,455.25672371638143,460.26894865525674,465.28117359413204,470.29339853300735,475.30562347188265,480.31784841075796,485.33007334963327,490.3422982885086,495.3545232273839,500.3667481662592,505.3789731051345,510.3911980440098,515.4034229828851,520.4156479217604,525.4278728606357,530.440097799511,535.4523227383863,540.4645476772616,545.4767726161369,550.4889975550122,555.5012224938876,560.5134474327629,565.5256723716382,570.5378973105135,575.5501222493888,580.5623471882641,585.5745721271394,590.5867970660147,595.59902200489,600.6112469437653,605.6234718826406,610.6356968215159,615.6479217603912,620.6601466992665,625.6723716381418,630.6845965770171,635.6968215158925,640.7090464547678,645.7212713936431,650.7334963325184,655.7457212713937,660.757946210269,665.7701711491443,670.7823960880196,675.7946210268949,680.8068459657702,685.8190709046455,690.8312958435208,695.8435207823961,700.8557457212714,705.8679706601467,710.880195599022,715.8924205378974,720.9046454767727,725.916870415648,730.9290953545233,735.9413202933986,740.9535452322739,745.9657701711492,750.9779951100245,755.9902200488998,761.0024449877751,766.0146699266504,771.0268948655257,776.039119804401,781.0513447432763,786.0635696821516,791.075794621027,796.0880195599022,801.1002444987776,806.1124694376529,811.1246943765282,816.1369193154035,821.1491442542788,826.1613691931541,831.1735941320293,836.1858190709046,841.1980440097799,846.2102689486552,851.2224938875305,856.2347188264058,861.2469437652811,866.2591687041564,871.2713936430317,876.283618581907,881.2958435207823,886.3080684596576,891.320293398533,896.3325183374083,901.3447432762836,906.3569682151589,911.3691931540342,916.3814180929095,921.3936430317848,926.4058679706601,931.4180929095354,936.4303178484107,941.442542787286,946.4547677261613,951.4669926650366,956.4792176039119,961.4914425427872,966.5036674816625,971.5158924205379,976.5281173594132,981.5403422982885,986.5525672371638,991.5647921760391,996.5770171149144,1001.5892420537897,1006.601466992665,1011.6136919315403,1016.6259168704156,1021.6381418092909,1026.650366748166,1031.6625916870416,1036.6748166259167,1041.6870415647923,1046.6992665036673,1051.7114914425429,1056.723716381418,1061.7359413202935,1066.7481662591686,1071.760391198044,1076.7726161369192,1081.7848410757947,1086.7970660146698,1091.8092909535453,1096.8215158924204,1101.833740831296,1106.845965770171,1111.8581907090465,1116.8704156479216,1121.8826405867972,1126.8948655256722,1131.9070904645478,1136.9193154034228,1141.9315403422984,1146.9437652811735,1151.955990220049,1156.968215158924,1161.9804400977996,1166.9926650366747,1172.0048899755502,1177.0171149144253,1182.0293398533008,1187.041564792176,1192.0537897310514,1197.0660146699265,1202.078239608802,1207.0904645476771,1212.1026894865527,1217.1149144254277,1222.1271393643033,1227.1393643031784,1232.151589242054,1237.163814180929,1242.1760391198045,1247.1882640586796,1252.200488997555,1257.2127139364302,1262.2249388753057,1267.2371638141808,1272.2493887530563,1277.2616136919314,1282.273838630807,1287.286063569682,1292.2982885085576,1297.3105134474326,1302.3227383863082,1307.3349633251833,1312.3471882640586,1317.3594132029339,1322.3716381418092,1327.3838630806845,1332.3960880195598,1337.408312958435,1342.4205378973104,1347.4327628361857,1352.444987775061,1357.4572127139363,1362.4694376528116,1367.481662591687,1372.4938875305622,1377.5061124694375,1382.5183374083128,1387.5305623471882,1392.5427872860635,1397.5550122249388,1402.567237163814,1407.5794621026894,1412.5916870415647,1417.60391198044,1422.6161369193153,1427.6283618581906,1432.640586797066,1437.6528117359412,1442.6650366748165,1447.6772616136918,1452.6894865525671,1457.7017114914424,1462.7139364303177,1467.726161369193,1472.7383863080684,1477.7506112469437,1482.762836185819,1487.7750611246943,1492.7872860635696,1497.799511002445,1502.8117359413202,1507.8239608801955,1512.8361858190708,1517.848410757946,1522.8606356968214,1527.8728606356967,1532.885085574572,1537.8973105134473,1542.9095354523226,1547.921760391198,1552.9339853300733,1557.9462102689486,1562.9584352078239,1567.9706601466992,1572.9828850855745,1577.9951100244498,1583.007334963325,1588.0195599022004,1593.0317848410757,1598.044009779951,1603.0562347188263,1608.0684596577016,1613.080684596577,1618.0929095354522,1623.1051344743275,1628.1173594132028,1633.1295843520782,1638.1418092909535,1643.1540342298288,1648.166259168704,1653.1784841075794,1658.1907090464547,1663.20293398533,1668.2151589242053,1673.2273838630806,1678.239608801956,1683.2518337408312,1688.2640586797065,1693.2762836185818,1698.2885085574571,1703.3007334963324,1708.3129584352077,1713.325183374083,1718.3374083129584,1723.3496332518337,1728.361858190709,1733.3740831295843,1738.3863080684596,1743.398533007335,1748.4107579462102,1753.4229828850855,1758.4352078239608,1763.4474327628361,1768.4596577017114,1773.4718826405867,1778.484107579462,1783.4963325183373,1788.5085574572126,1793.520782396088,1798.5330073349633,1803.5452322738386,1808.5574572127139,1813.5696821515892,1818.5819070904645,1823.5941320293398,1828.606356968215,1833.6185819070904,1838.6308068459657,1843.643031784841,1848.6552567237163,1853.6674816625916,1858.679706601467,1863.6919315403422,1868.7041564792175,1873.7163814180929,1878.7286063569682,1883.7408312958435,1888.7530562347188,1893.765281173594,1898.7775061124694,1903.7897310513447,1908.80195599022,1913.8141809290953,1918.8264058679706,1923.838630806846,1928.8508557457212,1933.8630806845965,1938.8753056234718,1943.8875305623471,1948.8997555012224,1953.9119804400978,1958.924205378973,1963.9364303178484,1968.9486552567237,1973.960880195599,1978.9731051344743,1983.9853300733496,1988.997555012225,1994.0097799511002,1999.0220048899755,2004.0342298288508,2009.0464547677261,2014.0586797066014,2019.0709046454767,2024.083129584352,2029.0953545232273,2034.1075794621026,2039.119804400978,2044.1320293398533,2049.1442542787286,2054.156479217604,2059.168704156479,2064.1809290953543,2069.19315403423,2074.2053789731053,2079.2176039119804,2084.2298288508555,2089.242053789731,2094.2542787286066,2099.2665036674816,2104.2787286063567,2109.2909535452322,2114.303178484108,2119.315403422983,2124.327628361858,2129.3398533007335,2134.352078239609,2139.364303178484,2144.376528117359,2149.3887530562347,2154.40097799511,2159.4132029339853,2164.4254278728604,2169.437652811736,2174.4498777506114,2179.4621026894865,2184.4743276283616,2189.486552567237,2194.4987775061127,2199.5110024449878,2204.523227383863,2209.5354523227384,2214.547677261614,2219.559902200489,2224.572127139364,2229.5843520782396,2234.596577017115,2239.60880195599,2244.6210268948653,2249.633251833741,2254.6454767726163,2259.6577017114914,2264.6699266503665,2269.682151589242,2274.694376528117,2279.7066014669927,2284.7188264058677,2289.731051344743,2294.7432762836183,2299.755501222494,2304.767726161369,2309.779951100244,2314.7921760391196,2319.804400977995,2324.81662591687,2329.8288508557453,2334.841075794621,2339.8533007334963,2344.8655256723714,2349.8777506112465,2354.889975550122,2359.9022004889976,2364.9144254278726,2369.9266503667477,2374.9388753056232,2379.951100244499,2384.963325183374,2389.975550122249,2394.9877750611245,2400.0],"y":[null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,12.1,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]}],                        {"annotations":[{"showarrow":false,"text":"Sentinel-2 MSI","x":200,"y":0},{"showarrow":false,"text":"Sentinel-3 OLCI","x":200,"y":1},{"showarrow":false,"text":"Sentinel-3 SLSTR","x":200,"y":2},{"showarrow":false,"text":"Landsat OLCI","x":200,"y":3},{"showarrow":false,"text":"Landsat ETM+","x":200,"y":4},{"showarrow":false,"text":"Landsat TM","x":200,"y":5},{"showarrow":false,"text":"Landsat MSS","x":200,"y":6},{"showarrow":false,"text":"PlanetScope","x":200,"y":7},{"showarrow":false,"text":"Pleiades","x":200,"y":8},{"showarrow":false,"text":"Spot-6","x":200,"y":9},{"showarrow":false,"text":"Spot-7","x":200,"y":10},{"showarrow":false,"text":"WorldView02/03","x":200,"y":11},{"showarrow":false,"text":"WorldView04/GeoEye01","x":200,"y":12}],"autosize":false,"height":700,"images":[{"sizex":0.09,"sizey":0.09,"source":"https://raw.githubusercontent.com/sertit/eoreader/master/docs/_static/eoreader.png","x":1,"xanchor":"right","xref":"paper","y":1.005,"yanchor":"bottom","yref":"paper"},{"sizex":0.09,"sizey":0.09,"source":"https://raw.githubusercontent.com/sertit/eoreader/master/docs/_static/logo-sertit.png","x":0.95,"xanchor":"right","xref":"paper","y":1.005,"yanchor":"bottom","yref":"paper"}],"legend":{"title":{"text":"Band Names"}},"margin":{"b":0,"l":0,"pad":0,"r":0,"t":70},"plot_bgcolor":"aliceblue","template":{"data":{"bar":[{"error_x":{"color":"#2a3f5f"},"error_y":{"color":"#2a3f5f"},"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"bar"}],"barpolar":[{"marker":{"line":{"color":"#E5ECF6","width":0.5},"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"barpolar"}],"carpet":[{"aaxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"baxis":{"endlinecolor":"#2a3f5f","gridcolor":"white","linecolor":"white","minorgridcolor":"white","startlinecolor":"#2a3f5f"},"type":"carpet"}],"choropleth":[{"colorbar":{"outlinewidth":0,"ticks":""},"type":"choropleth"}],"contour":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"contour"}],"contourcarpet":[{"colorbar":{"outlinewidth":0,"ticks":""},"type":"contourcarpet"}],"heatmap":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"heatmap"}],"heatmapgl":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"heatmapgl"}],"histogram":[{"marker":{"pattern":{"fillmode":"overlay","size":10,"solidity":0.2}},"type":"histogram"}],"histogram2d":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"histogram2d"}],"histogram2dcontour":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"histogram2dcontour"}],"mesh3d":[{"colorbar":{"outlinewidth":0,"ticks":""},"type":"mesh3d"}],"parcoords":[{"line":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"parcoords"}],"pie":[{"automargin":true,"type":"pie"}],"scatter":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatter"}],"scatter3d":[{"line":{"colorbar":{"outlinewidth":0,"ticks":""}},"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatter3d"}],"scattercarpet":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scattercarpet"}],"scattergeo":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scattergeo"}],"scattergl":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scattergl"}],"scattermapbox":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scattermapbox"}],"scatterpolar":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatterpolar"}],"scatterpolargl":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatterpolargl"}],"scatterternary":[{"marker":{"colorbar":{"outlinewidth":0,"ticks":""}},"type":"scatterternary"}],"surface":[{"colorbar":{"outlinewidth":0,"ticks":""},"colorscale":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"type":"surface"}],"table":[{"cells":{"fill":{"color":"#EBF0F8"},"line":{"color":"white"}},"header":{"fill":{"color":"#C8D4E3"},"line":{"color":"white"}},"type":"table"}]},"layout":{"annotationdefaults":{"arrowcolor":"#2a3f5f","arrowhead":0,"arrowwidth":1},"autotypenumbers":"strict","coloraxis":{"colorbar":{"outlinewidth":0,"ticks":""}},"colorscale":{"diverging":[[0,"#8e0152"],[0.1,"#c51b7d"],[0.2,"#de77ae"],[0.3,"#f1b6da"],[0.4,"#fde0ef"],[0.5,"#f7f7f7"],[0.6,"#e6f5d0"],[0.7,"#b8e186"],[0.8,"#7fbc41"],[0.9,"#4d9221"],[1,"#276419"]],"sequential":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]],"sequentialminus":[[0.0,"#0d0887"],[0.1111111111111111,"#46039f"],[0.2222222222222222,"#7201a8"],[0.3333333333333333,"#9c179e"],[0.4444444444444444,"#bd3786"],[0.5555555555555556,"#d8576b"],[0.6666666666666666,"#ed7953"],[0.7777777777777778,"#fb9f3a"],[0.8888888888888888,"#fdca26"],[1.0,"#f0f921"]]},"colorway":["#636efa","#EF553B","#00cc96","#ab63fa","#FFA15A","#19d3f3","#FF6692","#B6E880","#FF97FF","#FECB52"],"font":{"color":"#2a3f5f"},"geo":{"bgcolor":"white","lakecolor":"white","landcolor":"#E5ECF6","showlakes":true,"showland":true,"subunitcolor":"white"},"hoverlabel":{"align":"left"},"hovermode":"closest","mapbox":{"style":"light"},"paper_bgcolor":"white","plot_bgcolor":"#E5ECF6","polar":{"angularaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"bgcolor":"#E5ECF6","radialaxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"scene":{"xaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","gridwidth":2,"linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white"},"yaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","gridwidth":2,"linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white"},"zaxis":{"backgroundcolor":"#E5ECF6","gridcolor":"white","gridwidth":2,"linecolor":"white","showbackground":true,"ticks":"","zerolinecolor":"white"}},"shapedefaults":{"line":{"color":"#2a3f5f"}},"ternary":{"aaxis":{"gridcolor":"white","linecolor":"white","ticks":""},"baxis":{"gridcolor":"white","linecolor":"white","ticks":""},"bgcolor":"#E5ECF6","caxis":{"gridcolor":"white","linecolor":"white","ticks":""}},"title":{"x":0.05},"xaxis":{"automargin":true,"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","zerolinewidth":2},"yaxis":{"automargin":true,"gridcolor":"white","linecolor":"white","ticks":"","title":{"standoff":15},"zerolinecolor":"white","zerolinewidth":2}}},"title":{"text":"<b>EOReader Optical Band Mapping</b>"},"width":1100,"xaxis":{"showgrid":false,"tickvals":[300,400,500,600,700,800,900,1000,1100,1200,1300,1400,1500,1600,1700,1800,1900,2000,2100,2200,2300],"title":{"text":"Wavelength (nm)"}},"yaxis":{"showticklabels":false,"tickvals":[-0.5,0.5,1.5,2.5,3.5,4.5,5.5,6.5,7.5,8.5,9.5,10.5,11.5,12.5],"title":{"text":"Sensors"},"zeroline":false}},                        {"responsive": true}                    )                };                            </script>        </div>

### Cloud bands

Maximum 5 cloud bands are available, according to the files provided in the data. All the bands are rasterized and
orthorectified if needed (for Sentinel-2 or 3 data for example), ready to be stacked.

The only difference with the other bands is that the cloud bands are provided in `uint8` and have a nodata equal to 255.

- {meth}`~eoreader.bands.bands.CloudsBandNames.RAW_CLOUDS`: Raw Cloud file as provided (the only changes are the
  orthorectification and rasterization). Can provide other flags, or cloud probability.
- {meth}`~eoreader.bands.bands.CloudsBandNames.CLOUDS`: Cloud presence (1) or absence (0). If clouds are provided in
  probabilities, their presence is determined according to Landsat definition (proba> 67%)
- {meth}`~eoreader.bands.bands.CloudsBandNames.CIRRUS`: Cirrus presence (1) or absence (0). If clouds are provided in
  probabilities, their presence is determined according to Landsat definition (proba> 67%)
- {meth}`~eoreader.bands.bands.CloudsBandNames.SHADOWS`: Shadows presence (1) or absence (0). If clouds are provided in
  probabilities, their presence is determined according to Landsat definition (proba> 67%)
- {meth}`~eoreader.bands.bands.CloudsBandNames.ALL_CLOUDS`: Cloud **OR** Cirrus **OR** Shadows presence (1) or absence (
  0). Do not take into account missing bands (i.e. for Landsat MSS sensors, `ALL_CLOUDS` == `CLOUDS`)

|Satellites | Clouds Bands|
|--- | ---|
|Sentinel-2 | `RAW_CLOUDS`, `CLOUDS`, `CIRRUS`, `ALL_CLOUDS`|
|Sentinel-2 Theia | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `CIRRUS`, `ALL_CLOUDS`|
|Sentinel-3 OLCI | *No cloud file available for S3-OLCI data* |
|Sentinel-3 SLSTR | `RAW_CLOUDS`, `CLOUDS`, `CIRRUS`, `ALL_CLOUDS`|
|Landsat 8 | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `CIRRUS`, `ALL_CLOUDS`|
|Landsat 7 | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `ALL_CLOUDS`|
|Landsat 5 TM | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `ALL_CLOUDS`|
|Landsat 4 TM | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `ALL_CLOUDS`|
|Landsat 5 MSS | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`|
|Landsat 4 MSS | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`|
|Landsat 3 | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`|
|Landsat 2 | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`|
|Landsat 1 | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`|
|PlanetScope | `RAW_CLOUDS`, `CLOUDS`, `SHADOWS`, `CIRRUS`, `ALL_CLOUDS`|
|Pleiades | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`|
|SPOT 6-7 | `RAW_CLOUDS`, `CLOUDS`, `ALL_CLOUDS`|

### DEM bands

Optical satellites can all load {meth}`~eoreader.bands.bands.DemBandNames.DEM`, {meth}`~eoreader.bands.bands.DemBandNames.SLOPE`
and {meth}`~eoreader.bands.bands.DemBandNames.HILLSHADE` bands. The `SLOPE` and `HILLSHADE` bands are computed with
the [`gdaldem`](https://gdal.org/programs/gdaldem.html) tool.

Use the environment variable `EOREADER_DEM_PATH` to position your worldwide DEM. You can
use both a local path e.g. `/mnt/dataserver/dems/srtm_30_v4/index.vrt` or `\\dataserver\DEMS\srtm_30_v4\index.vrt` or
a URL pointing to a web resources hosted on a S3 compatible storage e.g. 
`https://s3.storage.com/dem-bucket/srtm_cog.tif` (not available on Windows for now).

### Available index

|Index | Needed bands | Accepted satellites|
|--- | --- | ---|
|{meth}`~eoreader.bands.index.AFRI_1_6` | `NIR`, `SWIR_1` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.AFRI_2_1` | `NIR`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.AWEInsh` | `BLUE`, `GREEN`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.AWEIsh` | `GREEN`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.BAI` | `RED`, `NIR` | All optical satellites|
|{meth}`~eoreader.bands.index.BSI` | `BLUE`, `RED`, `NIR`, `SWIR_1` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.CIG` | `GREEN`, `NIR` | All optical satellites|
|{meth}`~eoreader.bands.index.DSWI` | `GREEN`, `RED`, `NIR`, `SWIR_1` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.GLI` | `GREEN`, `RED`, `BLUE` | Sentinel-2, Sentinel-3 OLCI, Landsat OLCI, (E)TM, PlanetScope, Pleiades, SPOT 6-7|
|{meth}`~eoreader.bands.index.GNDVI` | `GREEN`, `NIR` | All optical satellites|
|{meth}`~eoreader.bands.index.MNDWI` | `GREEN`, `SWIR_1` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.NBR` | `NNIR`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.NDGRI` | `GREEN`, `RED` | All optical satellites|
|{meth}`~eoreader.bands.index.NDMI` | `NIR`, `SWIR_1` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.NDRE2` | `NIR`, `VRE_1` | Sentinel-2, Sentinel-3 OLCI, Landsat MSS|
|{meth}`~eoreader.bands.index.NDRE3` | `NIR`, `VRE_2` | Sentinel-2, Sentinel-3 OLCI, Landsat MSS|
|{meth}`~eoreader.bands.index.NDVI` | `RED`, `NIR` | All optical satellites|
|{meth}`~eoreader.bands.index.NDWI` | `GREEN`, `NIR` | All optical satellites|
|{meth}`~eoreader.bands.index.RDI` | `NNIR`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.RGI` | `GREEN`, `RED` | All optical satellites|
|{meth}`~eoreader.bands.index.RI` | `GREEN`, `VRE_1` | Sentinel-2, Sentinel-3 OLCI, Landsat MSS, PlanetScope (5 bands)|
|{meth}`~eoreader.bands.index.SRSWIR` | `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.TCBRI` | `BLUE`, `GREEN`, `RED`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.TCGRE` | `BLUE`, `GREEN`, `RED`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.TCWET` | `BLUE`, `GREEN`, `RED`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|
|{meth}`~eoreader.bands.index.WI` | `GREEN`, `RED`, `NIR`, `SWIR_1`, `SWIR_2` | Sentinel-2, Sentinel-3 SLSTR, Landsat OLCI, (E)TM|

## Default SNAP resolution

You can override default SNAP resolution (in meters) when orthorecifying SAR and S3 bands by setting the following
environment variables:

- `EOREADER_S3_DEFAULT_RES` (500m for SLSTR and 300m for OLCI data by default)

## Documentary Sources

### Landsat

- [Collection 1 vs Collection 2](https://www.usgs.gov/media/files/landsat-collection-1-vs-collection-2-summary)
- [Quality assessment Collection 1](https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-1-level-1-quality-assessment-band)
- [Quality assessment Collection 2](https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-2-quality-assessment-bands)
- [MSS Collection 2 Data Format](https://www.usgs.gov/media/files/landsat-1-5-mss-collection-2-level-1-data-format-control-book)
- [TM Collection 2 Data Format](https://www.usgs.gov/media/files/landsat-4-5-tm-collection-2-level-1-data-format-control-book)
- [ETM Collection 2 Data Format](https://www.usgs.gov/media/files/landsat-7-etm-collection-2-level-1-data-format-control-book)
- [OLCI Collection 2 Data Format](https://www.usgs.gov/media/files/landsat-8-level-1-data-format-control-book)

### Sentinel-2

- [Cloud masks](https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-2-msi/level-1c/cloud-masks)
- [Product Specification](https://sentinel.esa.int/documents/247904/349490/S2_MSI_Product_Specification.pdf)

### Sentinel-2 Theia

- [Product Format](https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/)

### Sentinel-3

- [OLCI Product Format](https://sentinel.esa.int/documents/247904/1872756/Sentinel-3-OLCI-Product-Data-Format-Specification-OLCI-Level-1)
- [SLSTR Clouds](https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-3-slstr/level-1/cloud-identification)

### PlanetScope

- [Product Specification](https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf)
- [Instruments](https://developers.planet.com/docs/apis/data/sensors/)
- [Usable Data Mask](https://developers.planet.com/docs/data/udm-2/)
- [On Medium](https://medium.com/geoplexing/getting-started-with-planet-imagery-part-3-items-and-ordering-476a1a21618c)

### DIMAP V2: Pleiades, SPOT 6-7
- [DIMAP V2 Format](https://www.intelligence-airbusds.com/en/8723-pleiades-and-spot-6-7-format-delivery)
- [Pleiades User Guide (2019)](https://engesat.com.br/wp-content/uploads/PleiadesUserGuide-17062019.pdf)
- [SPOT 6-7 User Guide (2019)](https://earth.esa.int/eogateway/documents/20142/37627/SPOT-6-7-imagery-user-guide.pdf)
- [Request Form(2017)](https://www.intelligence-airbusds.com/files/pmedia/public/r44226_9_airbus_data_request_form_may_2017.pdf)

### Band mapping

- You can find a magnificent band comparison chart on the [Imagico](http://blog.imagico.de/satellite-comparison-update/)
  blog.
- [L8-S2](https://reader.elsevier.com/reader/sd/pii/S0034425718301883)
- [L8-S2](https://landsat.gsfc.nasa.gov/wp-content/uploads/2015/06/Landsat.v.Sentinel-2.png)
- [L4/L5, MSS-TM](https://landsat.gsfc.nasa.gov/the-multispectral-scanner-system/)
- [All Landsats](https://landsat.gsfc.nasa.gov/wp-content/uploads/2016/10/all_Landsat_bands.png)
- [S2](https://discovery.creodias.eu/dataset/72181b08-a577-4d55-8ece-d8485167beb7/resource/d8f5dd92-b35c-46ee-98a2-0879dad03fce/download/res_band_s2_1.png)
- [S3 OLCI](https://discovery.creodias.eu/dataset/a0960a9b-c9c4-46db-bca5-ec79d0dda32b/resource/de8300a4-08cd-41aa-96ec-d9813115cc08/download/s3_res_band_ol.png)
- [S3 SLSTR](https://discovery.creodias.eu/dataset/ea8f247e-d193-4368-8cf6-8687a03a5306/resource/8e5c485a-d832-42be-ad9c-af500b468f29/download/s3_slcs.png)
- [S2 and PlanetScope](https://developers.planet.com/docs/apis/data/sensors/#the-psbsd-instrument)

### Index

- [Index consistency](https://www.indexdatabase.de/)
- Specific sources inside the index function documentation in {meth}`~eoreader.bands.index`
